/**
 * apeman bud for guide files.
 * @memberof module:apeman-bud-guide/lib
 * @function setup
 * @param {object} params - Template params.
 * @returns {object} - Coz bud configuration.
 */

'use strict'

const argx = require('argx')
const fs = require('fs')
const assert = require('assert')
const expandglob = require('expandglob')
const path = require('path')
const stringcase = require('stringcase')
const _tmpl = require('./_tmpl')

/** @lends setup */
function setup (params = {}) {
  let { name, pkg } = params

  assert(name, 'params.name is required.')
  assert(pkg, 'params.pkg is required.')

  return [].concat(name).map((name, i) => {
    let tmpl = _tmpl(name)
    return {
      force: false,
      mode: '644',
      path: `${_numPrefix(i)} - ${stringcase.sentencecase(name)}.md`,
      tmpl: tmpl,
      data: {
        pkg,
        name,
        params,
        generator: 'coz',
        today: new Date().toLocaleDateString(),
        wiki: expandglob.sync(params.wiki || [])
          .map((filename) => path.basename(filename, path.extname(filename)))
          .map((name) => ({ url: name.replace(/\s/g, '-'), name }))
      }
    }
  })
}

function _numPrefix (value) {
  let prefix = String(value)
  while (prefix.length < 2) {
    prefix = '0' + prefix
  }
  return prefix
}
module.exports = setup
